#!/usr/bin/env python


import cv2
import numpy as np

# HSV values to define a colour range.
colorLow = np.array([40,0,0])
colorHigh = np.array([75,255,25])

def find_target(image) :
  # Blur methods available, comment or uncomment to try different blur methods.
  blur = cv2.GaussianBlur(image, (7, 7), 0)

  # HSV (Hue, Saturation, Value).
  # Convert the image to HSV colour model.
  hsv = cv2.cvtColor(blur, cv2.COLOR_BGR2HSV)

  mask = cv2.inRange(hsv, colorLow, colorHigh)

  kernal = cv2.getStructuringElement(cv2.MORPH_ELLIPSE, (7, 7))
  mask = cv2.morphologyEx(mask, cv2.MORPH_CLOSE, kernal)
  mask = cv2.morphologyEx(mask, cv2.MORPH_OPEN, kernal)

  bmask = cv2.GaussianBlur(mask, (5,5),0)

  # Take the moments to get the centroid
  moments = cv2.moments(bmask)
  m00 = moments['m00']
  centroid_x, centroid_y = None, None
  if m00 != 0:
      centroid_x = int(moments['m10']/m00)
      centroid_y = int(moments['m01']/m00)

  # Use centroid if it exists
  if centroid_x != None and centroid_y != None:
      return (centroid_x - 320, centroid_y)

  return None


def getVideoCapture() :
  return cv2.VideoCapture(0)

if __name__ == "__main__":

  capture = getVideoCapture()
  while True:

    okay, image = capture.read()
    if okay:
      target = find_target(image)
      if target:
        print("target x,y:",target)
      else:
        print("no target found")

    k = cv2.waitKey(2000) & 0xFF
    if k == 27:
      break
